BoxError

Struct BoxError 

pub struct BoxError { /* private fields */ }
Structured info about an error which can happen as a result of an internal API or a remote procedure call.

Can also be used in user code to return structured error info from stored procedures.

Implementations

Source

impl BoxError

pub fn new(code: impl Into<u32>, message: impl Into<String>) -> Self

Construct an error object with given error code and message. The resulting error will have file & line fields set from the caller’s location.

Use Self::with_location to override error location.

pub fn with_location( code: impl Into<u32>, message: impl Into<String>, file: impl Into<String>, line: u32, ) -> Self

Construct an error object with given error code and message and source location.

Use Self::new to use the caller’s location.

pub fn maybe_last() -> Result<(), Self>

Tries to get the information about the last API call error. If error was not set returns Ok(())

pub unsafe fn from_ptr(error_ptr: NonNull<BoxError>) -> Self

Create a BoxError from a poniter to the underlying struct.

Use Self::maybe_last to automatically get the last error set by tarantool.

Safety

The pointer must point to a valid struct of type BoxError.

Also must only be called from the tx thread.

pub fn last() -> Self

Get the information about the last API call error.

pub fn set_last(&self)

Set self as the last API call error. Useful when returning errors from stored prcoedures.

pub fn error_code(&self) -> u32

Return IPROTO error code

pub fn error_type(&self) -> &str

Return the error type, e.g. “ClientError”, “SocketError”, etc.

pub fn message(&self) -> &str

Return the error message

pub fn file(&self) -> Option<&str>

Return the name of the source file where the error was created, if it’s available.

pub fn line(&self) -> Option<u32>

Return the source line number where the error was created, if it’s available.

pub fn errno(&self) -> Option<u32>

Return the system errno value of the cause of this error, if it’s available.

You can use std::io::Error::from_raw_os_error to get more details for the returned error code.

pub fn cause(&self) -> Option<&Self>

Return the error which caused this one, if it’s available.

pub fn fields(&self) -> &HashMap<Box<str>, Value>

Return the map of additional fields.