Part

Struct Part 

pub struct Part<T = NumOrStr> {
    pub field: T,
    pub type: Option<FieldType>,
    pub collation: Option<String>,
    pub is_nullable: Option<bool>,
    pub path: Option<String>,
}
Index part

The T generic decides what is used to identify the field. It can be either a u32 for field index or String for field name, or NumOrStr for either.

Field names are used in picodata metadata, indices are used in tarantool’s metadata, while tarantool’s index creation API can accept either.

Fields

field: Ttype: Option<FieldType>collation: Option<String>is_nullable: Option<bool>path: Option<String>

Implementations

Source

impl<T> Part<T>

pub fn field(field: impl Into<T>) -> Self

pub fn field_type(self, type: FieldType) -> Self

pub fn collation(self, collation: impl Into<String>) -> Self

pub fn is_nullable(self, is_nullable: bool) -> Self

pub fn path(self, path: impl Into<String>) -> Self

pub fn new(fi: impl Into<T>, ft: FieldType) -> Self