#[repr(u32)]pub enum SayLevel {
Fatal = 0,
System = 1,
Error = 2,
Crit = 3,
Warn = 4,
Info = 5,
Verbose = 6,
Debug = 7,
}Expand description
Tarantool-native logging levels (use it with say())
Variants
Implementations
Sourceimpl SayLevel
impl SayLevel
Sourcepub const VARIANTS: &'static [Self]
pub const VARIANTS: &'static [Self]
A slice of all possible enum variants.
These are ordered in the order of definition in the source code.
Sourcepub const DISCRIMINANTS_ARE_SUBSEQUENT: bool = true
pub const DISCRIMINANTS_ARE_SUBSEQUENT: bool = true
If this is true then all of the enum variants have subsequent
discriminants and converting from integer to enum type is going
to use a more efficient implementation.
Sourcepub const fn variant_name(&self) -> &'static str
pub const fn variant_name(&self) -> &'static str
Returns the name of the variant as it is spelled in the source code.