Module tls

Module tls 

Contains an implementation of a custom async coio based TlsStream.

TlsStream is an asynchronous wrapper around ssl::SslStream<TcpStream> for use with Rust’s async/await functionality.

Unlike ssl::SslStream<S>, which only works with synchronous S: Read + Write types, TlsStream implements async traits. The underlying TcpStream implements both Read and Write to enable ssl::SslStream<TcpStream> to function. Internally, TcpStream uses non-blocking sockets.

Structs

TlsConfig
TlsConnector
Wrapper around ssl::SslConnector that configures TLS settings.
TlsStream
An asynchronous wrapper around ssl::SslStream<TcpStream> (to use with Rust async/await).